@@ -1,30 +1,14 @@
 
-.First.lib     <- function(lib, pkg) {
+.onLoad <- function(lib, pkg) {
+	require(methods)
 	require(utils)
-	v = packageDescription("rangeMapper")$Version
 	sep = paste("\n",paste(rep("-", 61),collapse = ""),"\n", collapse = "")
-	cat(paste(sep, "This is rangeMapper", v,
+	cat(paste(sep, "This is", pkg, packageDescription("rangeMapper")$Version,
 				   "\n   Type", sQuote("rangeMapper()"), "to start the graphical user interface.",
 				   "\n   Type", sQuote("?rangeMapper"), "to access the help files.",
 				   
-			 sep))
+			 sep, fill=TRUE))
 	
 	
 	
-	}
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+	}
\ No newline at end of file
